==> mx-repo-manager_23.11.tar.xz: BUILD/translations/mx-repo-manager_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="74"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="623"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Välj det APT förråd du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Välj snabbaste MX förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Välj snabbaste Debian förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Individuella källor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Återställ original APT sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="165"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="766"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="770"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ditt nya val kommer att träda i kraft nästa gång förråden uppdateras.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Lists</source>
        <translation>Listor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="296"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Förråd (markerade förråd är aktiva)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <location filename="../mainwindow.cpp" line="678"/>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <location filename="../mainwindow.cpp" line="718"/>
        <location filename="../mainwindow.cpp" line="726"/>
        <location filename="../mainwindow.cpp" line="743"/>
        <location filename="../mainwindow.cpp" line="749"/>
        <location filename="../mainwindow.cpp" line="836"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="473"/>
        <source>Could not change the repo.</source>
        <translation>Kunde inte ändra förrådet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="496"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>Please wait...</source>
        <translation>Var vänlig vänta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="558"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program för att välja standard Apt förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="562"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="563"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="578"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="588"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Du har valt MX Test Repo. Det är inte rekommendabelt att lämna dom aktiverade eller att uppgradera alla paket från det.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="591"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ett säkrare val är att installera paket individuellt med MX Paket Installerare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="625"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Välj det APT-förråd och källor du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="678"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="688"/>
        <location filename="../mainwindow.cpp" line="705"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="718"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>
Vet inte om den här appen fungerar med  antiX eller MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="727"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX version ej hittad eller utanför skalan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="743"/>
        <source>Could not download original APT files.</source>
        <translation>Kunde inte ladda ner original APT filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="749"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Kunde inte packa upp den nedladdade filen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Enabling AHS</source>
        <translation>Möjliggör AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="760"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Använder du AHS (Advanced Hardware Stack) förråd?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="767"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Original APT sources har återställts till ursprunglig status. Source-filer tillagda av användare i /etc/apt/sources.list.d/ har inte ändrats.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="837"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ett fel uppstod vid skrivande av fil: %1. Var vänlig kontrollera att du har tillräckligt mycket ledigt utrymme på disken.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="52"/>
        <location filename="../about.cpp" line="62"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="53"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="75"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="75"/>
        <location filename="../main.cpp" line="84"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="76"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="85"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
</TS>

==> mx-repo-manager_24.3.tar.xz: BUILD/translations/mx-repo-manager_sv.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sv">
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="17"/>
        <location filename="../mainwindow.cpp" line="73"/>
        <source>MX Repo Manager</source>
        <translation>MX Repo Manager</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="32"/>
        <location filename="../mainwindow.cpp" line="619"/>
        <source>Select the APT repository that you want to use:</source>
        <translation>Välj det APT förråd du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>MX repos</source>
        <translation>MX förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="84"/>
        <source>Select fastest MX repo for me</source>
        <translation>Välj snabbaste MX förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="110"/>
        <source>search</source>
        <translation>sök</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="168"/>
        <source>Debian repos</source>
        <translation>Debian förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="180"/>
        <source>Select fastest Debian repo for me</source>
        <translation>Välj snabbaste Debian förråd för mig</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="229"/>
        <source>Individual sources</source>
        <translation>Individuella källor</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="248"/>
        <source>Restore original APT sources</source>
        <translation>Återställ original APT sources</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="330"/>
        <source>Display help </source>
        <translation>Visa hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="333"/>
        <source>Help</source>
        <translation>Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="340"/>
        <source>Alt+H</source>
        <translation>Alt+H</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="385"/>
        <source>About this application</source>
        <translation>Om detta program</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="388"/>
        <source>About...</source>
        <translation>Om...</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="395"/>
        <source>Alt+B</source>
        <translation>Alt+B</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="411"/>
        <source>Quit application</source>
        <translation>Avsluta programmet</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="414"/>
        <source>Close</source>
        <translation>Stäng</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="421"/>
        <source>Alt+N</source>
        <translation>Alt+N</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="440"/>
        <source>Apply</source>
        <translation>Använd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="166"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="761"/>
        <source>Success</source>
        <translation>Det lyckades</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="167"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <location filename="../mainwindow.cpp" line="765"/>
        <source>Your new selection will take effect the next time sources are updated.</source>
        <translation>Ditt nya val kommer att träda i kraft nästa gång förråden uppdateras.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Lists</source>
        <translation>Listor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="297"/>
        <source>Sources (checked sources are enabled)</source>
        <translation>Förråd (markerade förråd är aktiva)</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <location filename="../mainwindow.cpp" line="674"/>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <location filename="../mainwindow.cpp" line="714"/>
        <location filename="../mainwindow.cpp" line="721"/>
        <location filename="../mainwindow.cpp" line="738"/>
        <location filename="../mainwindow.cpp" line="744"/>
        <location filename="../mainwindow.cpp" line="831"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>Could not change the repo.</source>
        <translation>Kunde inte ändra förrådet</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="495"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>Please wait...</source>
        <translation>Var vänlig vänta...</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="554"/>
        <source>About %1</source>
        <translation>Om %1</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="555"/>
        <source>Version: </source>
        <translation>Version:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="557"/>
        <source>Program for choosing the default APT repository</source>
        <translation>Program för att välja standard Apt förråd</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="559"/>
        <source>Copyright (c) MX Linux</source>
        <translation>Copyright (c) MX Linux</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="560"/>
        <source>%1 License</source>
        <translation>%1 Licens</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="574"/>
        <source>%1 Help</source>
        <translation>%1 Hjälp</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="583"/>
        <source>Warning</source>
        <translation>Varning</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="584"/>
        <source>You have selected MX Test Repo. It&apos;s not recommended to leave it enabled or to upgrade all the packages from it.</source>
        <translation>Du har valt MX Test Repo. Det är inte rekommendabelt att lämna dom aktiverade eller att uppgradera alla paket från det.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="587"/>
        <source>A safer option is to install packages individually with MX Package Installer.</source>
        <translation>Ett säkrare val är att installera paket individuellt med MX Paket Installerare.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="621"/>
        <source>Select the APT repository and sources that you want to use:</source>
        <translation>Välj det APT-förråd och källor du vill använda:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="674"/>
        <source>netselect-apt could not detect fastest repo.</source>
        <translation>netselect-apt kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="684"/>
        <location filename="../mainwindow.cpp" line="701"/>
        <source>Could not detect fastest repo.</source>
        <translation>Kunde inte hitta snabbaste förrådet.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="714"/>
        <source>Can&apos;t figure out if this app is running on antiX or MX</source>
        <translation>Vet inte om den här appen fungerar med  antiX eller MX</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="722"/>
        <source>MX version not detected or out of range: </source>
        <translation>MX version ej hittad eller utanför skalan:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="738"/>
        <source>Could not download original APT files.</source>
        <translation>Kunde inte ladda ner original APT filer</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="744"/>
        <source>Could not unzip downloaded file.</source>
        <translation>Kunde inte packa upp den nedladdade filen.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Enabling AHS</source>
        <translation>Möjliggör AHS</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="755"/>
        <source>Do you use AHS (Advanced Hardware Stack) repo?</source>
        <translation>Använder du AHS (Advanced Hardware Stack) förråd?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="762"/>
        <source>Original APT sources have been restored to the release status. User added source files in /etc/apt/sources.list.d/ have not been touched.</source>
        <translation>Original APT sources har återställts till ursprunglig status. Source-filer tillagda av användare i /etc/apt/sources.list.d/ har inte ändrats.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="832"/>
        <source>There was an error writing file: %1. Please check if you have enough free space on your drive</source>
        <translation>Ett fel uppstod vid skrivande av fil: %1. Var vänlig kontrollera att du har tillräckligt mycket ledigt utrymme på disken.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../about.cpp" line="49"/>
        <source>License</source>
        <translation>Licens</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="50"/>
        <location filename="../about.cpp" line="60"/>
        <source>Changelog</source>
        <translation>Ändringslogg</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="51"/>
        <source>Cancel</source>
        <translation>Avbryt</translation>
    </message>
    <message>
        <location filename="../about.cpp" line="73"/>
        <source>&amp;Close</source>
        <translation>&amp;Stäng</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="73"/>
        <location filename="../main.cpp" line="82"/>
        <source>Error</source>
        <translation>Fel</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="74"/>
        <source>You seem to be logged in as root, please log out and log in as normal user to use this program.</source>
        <translation>Du verkar vara inloggad som root, var vänlig logga ut och logga in som vanlig användare för att använda detta program.</translation>
    </message>
    <message>
        <location filename="../main.cpp" line="83"/>
        <source>You must run this program with admin access.</source>
        <translation>Du måste köra detta program med administratörsrättigheter.</translation>
    </message>
</context>
</TS>
